# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# COMMENT
class CommentSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment'
        model = models.Comment
        fields = '__all__'


class CommentListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_list'
        model = models.Comment
        fields = ('id', 'status', 'status_display', 'title', 'message', 'type', 'is_public', 'ordering',)


class CommentRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_retrieve'
        model = models.Comment
        fields = ('id', 'status', 'status_display', 'title', 'message', 'type', 'is_public', 'ordering')


class CommentCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_create'
        model = models.Comment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CommentRetrieveSerializer


class CommentUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_update'
        model = models.Comment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CommentRetrieveSerializer


class CommentPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_partial_update'
        model = models.Comment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CommentRetrieveSerializer


class CommentEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_enable'
        model = models.Comment
        fields = ()
        response_serializer = CommentRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class CommentDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_disable'
        model = models.Comment
        fields = ()
        response_serializer = CommentRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class CommentLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_comment_light'
        model = models.Comment
        fields = ('id', 'status', 'status_display', 'title', 'is_public',)


# ATTACHMENT
class AttachmentSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment'
        model = models.Attachment
        fields = '__all__'


class AttachmentListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_list'
        model = models.Attachment
        fields = ('id', 'status', 'status_display', 'name', 'type', 'attachment', 'description', 'ordering',)


class AttachmentRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_retrieve'
        model = models.Attachment
        fields = ('id', 'status', 'status_display', 'name', 'type', 'attachment', 'description', 'ordering',)


class AttachmentCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_create'
        model = models.Attachment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AttachmentRetrieveSerializer


class AttachmentUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_update'
        model = models.Attachment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AttachmentRetrieveSerializer


class AttachmentPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_partial_update'
        model = models.Attachment
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AttachmentRetrieveSerializer


class AttachmentEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_enable'
        model = models.Attachment
        fields = ()
        response_serializer = AttachmentRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class AttachmentDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_disable'
        model = models.Attachment
        fields = ('id', 'status', 'status_display', 'name',)
        response_serializer = AttachmentRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class AttachmentLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_miscellaneous_attachment_light'
        model = models.Attachment
        fields = ('id', 'status', 'status_display', 'name',)
